Documentation
¶
Overview ¶
Package cfdi contains a collection of tools to read and manage CFDI documents.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type InvoiceHeader ¶ added in v0.5.0
type InvoiceHeader struct {
IssuerRFC, AddresseeRFC, TotalAmount, UUID string
}
InvoiceHeader contains data used to validate a CFDI document.
func (*InvoiceHeader) Validate ¶ added in v0.5.0
func (i *InvoiceHeader) Validate() (*ValidationResult, error)
Validate checks if the document with the given parameters exists in SAT's system and is valid. BUG(inkatze): The namespace is not being parsed correctly in gosoap, so we have to make two calls to fix the element's namespace
type ValidationResult ¶
ValidationResult contains the processed results from the validation response
Notes ¶
Bugs ¶
The namespace is not being parsed correctly in gosoap, so we have to make two calls to fix the element's namespace
Click to show internal directories.
Click to hide internal directories.