Documentation
¶
Overview ¶
Package cfdi contains a collection of tools to read and manage CFDI documents.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type DocumentHeader ¶ added in v0.3.0
type DocumentHeader struct {
IssuerRFC, AddresseeRFC, TotalAmount, InvoiceUUID string
// contains filtered or unexported fields
}
DocumentHeader values used to uniquely identify CFDI documents
func (*DocumentHeader) Validate ¶ added in v0.3.0
func (d *DocumentHeader) Validate() (ValidationResult, error)
Validate checks if the document with the given parameters exists in SAT's system and is valid. BUG(inkatze): The namespace is not being parsed correctly in gosoap, so we have to make two calls to fix the element's namespace
type ValidationResult ¶
type ValidationResult struct {
RawResponse string
}
ValidationResult contains the processed results from the validation response
Notes ¶
Bugs ¶
The namespace is not being parsed correctly in gosoap, so we have to make two calls to fix the element's namespace
Click to show internal directories.
Click to hide internal directories.