Documentation
¶
Index ¶
Constants ¶
const ValidationURL = "https://consultaqr.facturaelectronica.sat.gob.mx/ConsultaCFDIService.svc?wsdl"
ValidationURL for the SOAP service to validate CFDI documents
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type DocumentHeaders ¶
type DocumentHeaders struct {
IssuerRFC, AddresseeRFC, TotalAmount, InvoiceUUID string
Client *gosoap.Client
}
DocumentHeaders values used to uniquely identify CFDI documents
func (*DocumentHeaders) SoapClient ¶
func (d *DocumentHeaders) SoapClient(url string) error
SoapClient creates a new SOAP client for the given url.
func (*DocumentHeaders) Validate ¶
func (d *DocumentHeaders) Validate() (ValidationResult, error)
Validate checks if the document with the given parameters exists in SAT's system and is valid. BUG(inkatze): The namespace is not being parsed correctly in gosoap.
type ValidationResult ¶
type ValidationResult struct {
RawResponse string
}
ValidationResult contains the processed results from the validation response
Notes ¶
Bugs ¶
The namespace is not being parsed correctly in gosoap.
Click to show internal directories.
Click to hide internal directories.